@@ -1,14 +1,15 @@
+from concurrent.futures import ThreadPoolExecutor, wait
+
 from dom.types.config import DomConfig
-from dom.infrastructure.api.domjudge import DomjudgeAPI
+from dom.infrastructure.api.domjudge import DomJudgeAPI
 from dom.infrastructure.secrets.manager import load_secret
 from dom.types.api.models import Contest
 from dom.core.services.problem.apply import apply_problems_to_contest
 from dom.core.services.team.apply import apply_teams_to_contest
 
-
 def apply_contests(config: DomConfig):
 
-    client = DomjudgeAPI(
+    client = DomJudgeAPI(
         base_url=f"http://localhost:{config.infra.port}",
         username="admin",
         password=load_secret("admin_password")
@@ -26,8 +27,9 @@ def apply_contests(config: DomConfig):
             )
         )
 
-        apply_problems_to_contest(client, contest_id, contest.problems)
-
-        apply_teams_to_contest(client, contest_id, contest.teams)
-
-
+        with ThreadPoolExecutor() as executor:
+            futures = [
+                executor.submit(apply_problems_to_contest, client, contest_id, contest.problems),
+                executor.submit(apply_teams_to_contest, client, contest_id, contest.teams)
+            ]
+            wait(futures)
\ No newline at end of file
