@@ -18,12 +18,12 @@ def find_config_or_default(file: Optional[str]) -> str:
             raise FileNotFoundError(f"Specified config file '{file}' not found.")
         return file
 
-    yaml_exists = os.path.isfile("dom-config.yaml")
-    yml_exists = os.path.isfile("dom-config.yml")
+    yaml_exists = os.path.isfile("dom-judge.yaml")
+    yml_exists = os.path.isfile("dom-judge.yml")
 
     if yaml_exists and yml_exists:
-        raise FileExistsError("Both 'dom-config.yaml' and 'dom-config.yml' exist. Please specify which one to use.")
+        raise FileExistsError("Both 'dom-judge.yaml' and 'dom-judge.yml' exist. Please specify which one to use.")
     if not yaml_exists and not yml_exists:
-        raise FileNotFoundError("No 'dom-config.yaml' or 'dom-config.yml' found. Please specify a config file.")
+        raise FileNotFoundError("No 'dom-judge.yaml' or 'dom-judge.yml' found. Please specify a config file.")
 
-    return "dom-config.yaml" if yaml_exists else "dom-config.yml"
+    return "dom-judge.yaml" if yaml_exists else "dom-judge.yml"
